use super::{PossessionData, PossessionType, WearData, DamageType, SoakData};
use crate::static_content::species::BodyPart;
use once_cell::sync::OnceCell;

pub fn data() -> &'static Vec<(PossessionType, PossessionData)> {
    static D: OnceCell<Vec<(PossessionType, PossessionData)>> =
        OnceCell::new();
    &D.get_or_init(|| vec!(
        (
            PossessionType::LeatherPants,
            PossessionData {
                display: "pair of leather pants",
                details: "Black leather pants that looks like they would protect you from falling off a motorbike, or maybe even offer some protection against certain weapons",
                aliases: vec!("leather pants", "pants"),
                wear_data: Some(WearData {
                    covers_parts: vec!(BodyPart::Groin, BodyPart::Legs),
                    thickness: 4.0,
                    dodge_penalty: 0.5,
                    soaks: vec!(
                        (DamageType::Beat,
                         SoakData {
                             min_soak: 1.0,
                             max_soak: 2.0,
                             damage_probability_per_soak: 0.1
                         }
                        ),
                        (DamageType::Slash,
                         SoakData {
                             min_soak: 2.0,
                             max_soak: 3.0,
                             damage_probability_per_soak: 0.1
                         }
                        ),
                        (DamageType::Pierce,
                         SoakData {
                             min_soak: 2.0,
                             max_soak: 3.0,
                             damage_probability_per_soak: 0.1
                         }
                        ),
                    ).into_iter().collect(),
                }),
                ..Default::default()
            }
        ),
    ))
}
