use super::{PossessionData, PossessionType, WeaponData, WeaponAttackData};
use crate::models::item::SkillType;
use once_cell::sync::OnceCell;

pub fn data() -> &'static Vec<(PossessionType, PossessionData)> {
    static D: OnceCell<Vec<(PossessionType, PossessionData)>> =
        OnceCell::new();
    &D.get_or_init(|| vec!(
        (PossessionType::AntennaWhip,
         PossessionData {
             display: "antenna whip",
             details: "A crudely fashioned whip made from a broken metal antenna. It looks a bit flimsy, but it \
                       might do you until you get a better weapon!",
             aliases: vec!("whip"),
             weapon_data: Some(WeaponData {
                 uses_skill: SkillType::Whips,
                 raw_min_to_learn: 0.0,
                 raw_max_to_learn: 2.0,
                 normal_attack: WeaponAttackData {
                     start_messages: vec!(
                         Box::new(|attacker, victim, exp|
                                  format!("{} lines up {} antenna whip for a strike on {}",
                                          &attacker.display_for_sentence(exp, 1, true),
                                          &attacker.pronouns.possessive,
                                          &victim.display_for_sentence(exp, 1, false),
                                  )
                         )
                     ),
                     success_messages: vec!(
                         Box::new(|attacker, victim, part, exp|
                                  format!("{}'s antenna whip scores a painful red line across {}'s {}",
                                          &attacker.display_for_sentence(exp, 1, true),
                                          &victim.display_for_sentence(exp, 1, false),
                                          &part.display(victim.sex.clone())
                                  )
                         )
                     ),
                     mean_damage: 3.0,
                     stdev_damage: 3.0,
                     ..Default::default()
                 },
                 ..Default::default()
             }),
             ..Default::default()
         }
        )
    ))
}
